from .ip import get_client_ip  # noqa

default_app_config = 'ipware.apps.IPwareConfig'

__author__ = 'Val Neekman @ Neekware Inc. [@vneekman]'
__description__ = "A Django application to retrieve user's IP address"
__version__ = '3.0.2'
